@@ -5,7 +5,7 @@
     Contact ........ jimmy@sqmail.org
     Home Site ...... http://www.sqmail.org/
     Program ........ Cpanel Vacation
-    Version ........ 0.2
+    Version ........ 0.1
     Purpose ........ Allows your users to set a Vacation Auto-Response when
                      using a host with CPanel
 
@@ -21,11 +21,11 @@ if (@file_exists(SM_PATH . 'plugins/cpanel_vacation/config.php')) {
         textdomain('cpanel_vacation');
 
         $optpage_blocks[] = array(
-            'name' => _("Vacation / Autoresponse"),
+            'name' => _("Vacation / Autoresponder"),
             'url'  => SM_PATH . 'plugins/cpanel_vacation/options.php',
             'desc' => _("Set up an auto-reply message for your incoming email.  This can be useful when you are away on vacation."),
             'js'   => false);
-        bindtextdomain('squirrelmail', SM_PATH . 'locale');
+
         textdomain('squirrelmail');
     }
 }
