@@ -5,31 +5,24 @@
     Contact ........ jimmy@sqmail.org
     Home Site ...... http://www.sqmail.org/
     Program ........ Cpanel Vacation
-    Version ........ 0.2
+    Version ........ 0.1
     Purpose ........ Allows your users to set a Vacation Auto-Response when
                      using a host with CPanel
 
 *******************************************************************************/
 
-    global $color, $username, $data_dir, $cpanel_vac_pw, $cpanel_vac_un;
-    if (@file_exists(SM_PATH . 'plugins/cpanel_vacation/config.php'))
-        include_once(SM_PATH . 'plugins/cpanel_vacation/config.php');
-    else
-        return;
+    global $color;
+
     $filename = getHashedFile($username, $data_dir, '');
     $status = getPref($filename, $username, 'cpanel_vacation_status');
 
-    if ($status == 1 && $cpanel_vac_pw != '' && $cpanel_vac_un != '') {
-        bindtextdomain('cpanel_vacation', SM_PATH . 'plugins/cpanel_vacation/locale');
-        textdomain('cpanel_vacation');
+    if ($status == 1 && $cpanel_vac_pw != '' & $cpanel_vac_un != '') {
         print "<table align=center border=0 cellpadding=1 cellspacing=0 bgcolor='" . $color[0] . "'><tr><td>
                    <table width=100% cellpadding=3 cellspacing=0 bgcolor='" . $color[4] . "'><tr><td>".
                        _("Your Vacation Auto Response is currently") . " <b>" . _("Enabled") . "</b>.<br>" .
                        _("Please click") . " <a href='" . SM_PATH . "plugins/cpanel_vacation/options.php'><b><u>" . _("here") . "</u></b></a> " . _("to disable it") .".
                    </td></tr></table>
                </td></tr></table><br>";
-        bindtextdomain('squirrelmail', SM_PATH . 'locale');
-        textdomain('squirrelmail');
     }
 
 ?>
\ No newline at end of file
